@@ -410,22 +410,28 @@ class HealSparseMap(object):
         Parameters
         ----------
         ra_or_theta : `float`, array-like
-           Angular coordinates of points on a sphere.
+            Angular coordinates of points on a sphere.
         dec_or_phi : `float`, array-like
-           Angular coordinates of points on a sphere.
+            Angular coordinates of points on a sphere.
         values : `np.ndarray`
-           Value or Array of values.  Must be same type as sparse_map.
+            Value or Array of values.  Must be same type as sparse_map.
         lonlat : `bool`, optional
-           If True, input angles are longitude and latitude in degrees.
-           Otherwise, they are co-latitude and longitude in radians.
+            If True, input angles are longitude and latitude in degrees.
+            Otherwise, they are co-latitude and longitude in radians.
         operation : `str`, optional
-           Operation to use to update values.  May be 'replace' (default),
-           'or', or 'and' (for bit masks)
+            Operation to use to update values.  May be 'replace' (default);
+            'add'; 'or', or 'and' (for bit masks).
 
         Raises
         ------
-        ValueError : Raised if positions do not resolve to unique
-           positions and operation is 'replace'.
+        ValueError
+            If positions do not resolve to unique positions and operation
+            is 'replace'.
+
+        Notes
+        -----
+        During the 'add' operation, if the default sentinel map value is not
+        equal to 0, then any default values will be set to 0 prior to addition.
         """
         return self.update_values_pix(hpg.angle_to_pixel(self._nside_sparse,
                                                          ra_or_theta,
@@ -442,23 +448,33 @@ class HealSparseMap(object):
         Parameters
         ----------
         pixels : `np.ndarray`
-           Integer array of sparse_map pixel values
+            Integer array of sparse_map pixel values
         values : `np.ndarray`
-           Value or Array of values.  Must be same type as sparse_map.
+            Value or Array of values.  Must be same type as sparse_map.
         operation : `str`, optional
-           Operation to use to update values.  May be 'replace' (default),
-           'or', or 'and' (for bit masks)
+            Operation to use to update values.  May be 'replace' (default);
+            'add'; 'or', or 'and' (for bit masks).
 
         Raises
         ------
-        ValueError : Raised if positions do not resolve to unique
-           positions and operation is 'replace'.
+        ValueError
+            Raised if pixels are not unique and operation is 'replace', or if
+            operation is not 'replace' on a recarray map.
+
+        Notes
+        -----
+        During the 'add' operation, if the default sentinel map value is not
+        equal to 0, then any default values will be set to 0 prior to addition.
         """
         if operation != 'replace':
-            if operation != 'or' and operation != 'and':
-                raise ValueError("Only replace, or, and and are supported operations")
-            if not self.is_integer_map or self._sentinel != 0:
-                raise ValueError("Can only use and/or with integer map with 0 sentinel")
+            if operation in ['or', 'and']:
+                if not self.is_integer_map or self._sentinel != 0:
+                    raise ValueError("Can only use and/or with integer map with 0 sentinel")
+            elif operation == 'add':
+                if self._is_rec_array:
+                    raise ValueError("Cannot use 'add' operation with a recarray map.")
+            else:
+                raise ValueError("Only 'replace', 'add', 'or', and 'and' are supported operations")
 
         if operation == 'replace':
             # Check for unique pixel positions
@@ -539,28 +555,31 @@ class HealSparseMap(object):
         out_cov = ~cov_mask[ipnest_cov]
 
         # Replace values for those pixels in the coverage map
+        _indices = _pix[in_cov] + self._cov_map[ipnest_cov[in_cov]]
         if is_single_value:
             if operation == 'replace':
-                self._sparse_map[_pix[in_cov] + self._cov_map[ipnest_cov[in_cov]]] = _values[0]
+                self._sparse_map[_indices] = _values[0]
+            elif operation == 'add':
+                # Put in a check to reset uncovered pixels to 0
+                if self._sentinel != 0:
+                    self._sparse_map[_indices[self._sparse_map[_indices] == self._sentinel]] = 0
+                np.add.at(self._sparse_map, _indices, _values[0])
             elif operation == 'or':
-                np.bitwise_or.at(self._sparse_map,
-                                 _pix[in_cov] + self._cov_map[ipnest_cov[in_cov]],
-                                 _values[0])
+                np.bitwise_or.at(self._sparse_map, _indices, _values[0])
             elif operation == 'and':
-                np.bitwise_and.at(self._sparse_map,
-                                  _pix[in_cov] + self._cov_map[ipnest_cov[in_cov]],
-                                  _values[0])
+                np.bitwise_and.at(self._sparse_map, _indices, _values[0])
         else:
             if operation == 'replace':
-                self._sparse_map[_pix[in_cov] + self._cov_map[ipnest_cov[in_cov]]] = _values[in_cov]
+                self._sparse_map[_indices] = _values[in_cov]
+            elif operation == 'add':
+                # Put in a check to reset uncovered pixels to 0
+                if self._sentinel != 0:
+                    self._sparse_map[_indices[self._sparse_map[_indices] == self._sentinel]] = 0
+                np.add.at(self._sparse_map, _indices, _values[in_cov])
             elif operation == 'or':
-                np.bitwise_or.at(self._sparse_map,
-                                 _pix[in_cov] + self._cov_map[ipnest_cov[in_cov]],
-                                 _values[in_cov])
+                np.bitwise_or.at(self._sparse_map, _indices, _values[in_cov])
             elif operation == 'and':
-                np.bitwise_and.at(self._sparse_map,
-                                  _pix[in_cov] + self._cov_map[ipnest_cov[in_cov]],
-                                  _values[in_cov])
+                np.bitwise_and.at(self._sparse_map, _indices, _values[in_cov])
 
         # Update the coverage map for the rest of the pixels (if necessary)
         if out_cov.sum() > 0:
@@ -575,30 +594,31 @@ class HealSparseMap(object):
             oldsize = len(self._sparse_map)
             self._reserve_cov_pix(new_cov_pix)
 
+            _indices = _pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] - oldsize
             if is_single_value:
                 if operation == 'replace':
-                    self._sparse_map[oldsize:][_pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] -
-                                               oldsize] = _values[0]
+                    self._sparse_map[oldsize:][_indices] = _values[0]
+                elif operation == 'add':
+                    # Put in a check to reset uncovered pixels to 0
+                    if self._sentinel != 0:
+                        self._sparse_map[oldsize:][_indices[self._sparse_map[_indices] == self._sentinel]] = 0
+                    np.add.at(self._sparse_map[oldsize:], _indices, _values[0])
                 elif operation == 'or':
-                    np.bitwise_or.at(self._sparse_map[oldsize:],
-                                     _pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] - oldsize,
-                                     _values[0])
+                    np.bitwise_or.at(self._sparse_map[oldsize:], _indices, _values[0])
                 elif operation == 'and':
-                    np.bitwise_and.at(self._sparse_map[oldsize:],
-                                      _pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] - oldsize,
-                                      _values[0])
+                    np.bitwise_and.at(self._sparse_map[oldsize:], _indices, _values[0])
             else:
                 if operation == 'replace':
-                    self._sparse_map[oldsize:][_pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] -
-                                               oldsize] = _values[out_cov]
+                    self._sparse_map[oldsize:][_indices] = _values[out_cov]
+                elif operation == 'add':
+                    # Put in a check to reset uncovered pixels to 0
+                    if self._sentinel != 0:
+                        self._sparse_map[oldsize:][_indices[self._sparse_map[_indices] == self._sentinel]] = 0
+                    np.add.at(self._sparse_map[oldsize:], _indices, _values[out_cov])
                 elif operation == 'or':
-                    np.bitwise_or.at(self._sparse_map[oldsize:],
-                                     _pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] - oldsize,
-                                     _values[out_cov])
+                    np.bitwise_or.at(self._sparse_map[oldsize:], _indices, _values[out_cov])
                 elif operation == 'and':
-                    np.bitwise_and.at(self._sparse_map[oldsize:],
-                                      _pix[out_cov] + self._cov_map[ipnest_cov[out_cov]] - oldsize,
-                                      _values[out_cov])
+                    np.bitwise_and.at(self._sparse_map[oldsize:], _indices, _values[out_cov])
 
     def set_bits_pix(self, pixels, bits, nest=True):
         """
